@@ -7,8 +7,8 @@ globals$DEBUG <- FALSE
 ##
 ## We reset the DB_PATH in .onLoad since we need to
 ## get the right one based on libpath
-globals$DB_PATH <- system.file("extdata", "pd.mirna.3.1.sqlite",
-                               package="pd.mirna.3.1")
+globals$DB_PATH <- system.file("extdata", "pd.mirna.4.0.sqlite",
+                               package="pd.mirna.4.0")
 if (nchar(globals$DB_PATH) == 0)
   stop("Unable to locate DB file")
 
@@ -18,14 +18,13 @@ initDbConnection <- function() {
 }
 
 getDb  <- function() {
-    if (!is.null(globals$dbCon) && isIdCurrent(globals$dbCon))
+    if (!is.null(globals$dbCon) && dbIsValid(globals$dbCon))
       return(globals$dbCon)
     initDbConnection()
 }
 
 closeDb <- function() {
-    ## FIXME: check for valid connection?
-    if (isIdCurrent(globals$dbCon)){
+    if (dbIsValid(globals$dbCon)){
         sapply(dbListResults(globals$dbCon), dbClearResult)
         dbDisconnect(globals$dbCon)
     }
@@ -33,8 +32,8 @@ closeDb <- function() {
 }
 
 .onAttach <- function(libname, pkgname) {
-    globals$DB_PATH <- system.file("extdata", "pd.mirna.3.1.sqlite",
-                                   package="pd.mirna.3.1",
+    globals$DB_PATH <- system.file("extdata", "pd.mirna.4.0.sqlite",
+                                   package="pd.mirna.4.0",
                                    lib.loc=libname)
     if (nchar(globals$DB_PATH) == 0)
       stop("Unable to locate DB file")
@@ -46,9 +45,9 @@ closeDb <- function() {
     closeDb()
 }
 
-pd.mirna.3.1 <- new("AffyExpressionPDInfo",
+pd.mirna.4.0 <- new("AffyExpressionPDInfo",
                     genomebuild="N/A",
                     getdb=getDb,
                     geometry=as.integer(strsplit("541;541", ";")[[1]]),
-                    annotation="pd.mirna.3.1")
+                    annotation="pd.mirna.4.0")
 
